==> lxqt-panel_0.16.1.orig.tar.xz: lxqt-panel-0.16.1/plugin-mainmenu/translations/mainmenu_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>LXQtMainMenu</name>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="106"/>
        <source>Search...</source>
        <translation>Ieškoti...</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="114"/>
        <source>Show/hide main menu</source>
        <translation>Rodyti/slėpti pagrindinį meniu</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="496"/>
        <source>Add to desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="504"/>
        <source>Question</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="505"/>
        <source>A file with the same name already exists.
Do you want to overwrite it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="511"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="512"/>
        <source>The file cannot be overwritten.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="518"/>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtMainMenuConfiguration</name>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Bendra</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="14"/>
        <source>Main Menu settings</source>
        <translation>Pagrindinio meniu nustatymai</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation>Piktograma:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>Mygtuko tekstas:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>Tinkintas šrifto dydis:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation> taškų</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="105"/>
        <source>Menu file</source>
        <translation>Meniu failas</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="111"/>
        <source>Menu file:</source>
        <translation>Meniu failas:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="156"/>
        <source>Search</source>
        <translation>Paieška</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="162"/>
        <source>Max. item width:</source>
        <translation>Didžiausias elemento plotis:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="169"/>
        <source>Show matching entries:</source>
        <translation>Rodyti atitinkančius įrašus:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="183"/>
        <source>Maximum visible items:</source>
        <translation>Daugiausia matomų elementų:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="190"/>
        <source>Filter menu entries</source>
        <translation>Filtruoti meniu įrašus</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="197"/>
        <source> px</source>
        <translation> pikselių</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="210"/>
        <source>Hide menu entries while searching</source>
        <translation>Slėpti meniu įrašus, kol ieškoma</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="217"/>
        <source>Clear search upon showing menu</source>
        <translation>Rodant meniu, išvalyti paiešką</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="127"/>
        <source>Keyboard Shortcut</source>
        <translation>Spartusis klavišas</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="146"/>
        <source>Click the button to record shortcut:</source>
        <translation>Spustelėkite mygtuką, kad įrašytumėte spartųjį klavišą:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="72"/>
        <source>Reset</source>
        <translation>Atstatyti</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="166"/>
        <source>Choose icon file</source>
        <translation>Pasirinkite piktogramos failą</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="168"/>
        <source>Images (*.svg *.png)</source>
        <translation>Paveikslai (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="180"/>
        <source>Choose menu file</source>
        <translation>Pasirinkite meniu failą</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="182"/>
        <source>Menu files (*.menu)</source>
        <translation>Meniu failai (*.menu)</translation>
    </message>
</context>
</TS>

==> lxqt-panel_0.17.1.orig.tar.xz: lxqt-panel-0.17.1/plugin-mainmenu/translations/mainmenu_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>LXQtMainMenu</name>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="106"/>
        <source>Search...</source>
        <translation>Ieškoti...</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="114"/>
        <source>Show/hide main menu</source>
        <translation>Rodyti/slėpti pagrindinį meniu</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="496"/>
        <source>Add to desktop</source>
        <translation>Pridėti į darbalaukį</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="504"/>
        <source>Question</source>
        <translation>Klausimas</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="505"/>
        <source>A file with the same name already exists.
Do you want to overwrite it?</source>
        <translation>Failas tokiu pavadinimu jau yra.
Ar norite jį perrašyti?</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="511"/>
        <source>Warning</source>
        <translation>Įspėjimas</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="512"/>
        <source>The file cannot be overwritten.</source>
        <translation>Failas negali būti perrašytas.</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="518"/>
        <source>Copy</source>
        <translation>Kopijuoti</translation>
    </message>
</context>
<context>
    <name>LXQtMainMenuConfiguration</name>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Bendra</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="14"/>
        <source>Main Menu settings</source>
        <translation>Pagrindinio meniu nustatymai</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation>Piktograma:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>Mygtuko tekstas:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>Tinkintas šrifto dydis:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation> taškų</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="105"/>
        <source>Menu file</source>
        <translation>Meniu failas</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="111"/>
        <source>Menu file:</source>
        <translation>Meniu failas:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="156"/>
        <source>Search</source>
        <translation>Paieška</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="162"/>
        <source>Max. item width:</source>
        <translation>Didžiausias elemento plotis:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="169"/>
        <source>Show matching entries:</source>
        <translation>Rodyti atitinkančius įrašus:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="183"/>
        <source>Maximum visible items:</source>
        <translation>Daugiausia matomų elementų:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="190"/>
        <source>Filter menu entries</source>
        <translation>Filtruoti meniu įrašus</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="197"/>
        <source> px</source>
        <translation> pikselių</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="210"/>
        <source>Hide menu entries while searching</source>
        <translation>Slėpti meniu įrašus, kol ieškoma</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="217"/>
        <source>Clear search upon showing menu</source>
        <translation>Rodant meniu, išvalyti paiešką</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="127"/>
        <source>Keyboard Shortcut</source>
        <translation>Spartusis klavišas</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="146"/>
        <source>Click the button to record shortcut:</source>
        <translation>Spustelėkite mygtuką, kad įrašytumėte spartųjį klavišą:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="72"/>
        <source>Reset</source>
        <translation>Atstatyti</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="166"/>
        <source>Choose icon file</source>
        <translation>Pasirinkite piktogramos failą</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="168"/>
        <source>Images (*.svg *.png)</source>
        <translation>Paveikslai (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="180"/>
        <source>Choose menu file</source>
        <translation>Pasirinkite meniu failą</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="182"/>
        <source>Menu files (*.menu)</source>
        <translation>Meniu failai (*.menu)</translation>
    </message>
</context>
</TS>
